@@ -203,9 +203,9 @@ import            sys
 import            logging
 import            warnings
 
-from   fsl.utils.platform import platform as fslplatform
-import fsl.utils.settings                 as fslsettings
-import fsleyes.version                    as version
+import fsl.utils.settings as fslsettings
+import fsleyes_widgets    as fwidgets
+import fsleyes.version    as version
 
 
 # The logger is assigned in
@@ -214,7 +214,7 @@ log = None
 
 
 # If set to True, logging will not be configured
-disableLogging = fslplatform.frozen
+disableLogging = False
 
 
 __version__ = version.__version__
@@ -223,9 +223,9 @@ module).
 """
 
 
-assetDir = op.join(op.dirname(__file__), '..')
-"""Base directory which contains all *FSLeyes* assets/resources (e.g. icon
-files). This is set in the :func:`initialise` function.
+assetDir = op.abspath(op.join(op.dirname(__file__), 'assets'))
+"""Directory which contains all *FSLeyes* assets/resources (e.g. icon
+files).
 """
 
 
@@ -233,23 +233,13 @@ def canWriteToAssetDir():
     """Returns ``True`` if the user can write to the FSLeyes asset directory,
     ``False`` otherwise.
     """
-    return os.access(op.join(assetDir, 'assets'), os.W_OK | os.X_OK)
+    return os.access(assetDir, os.W_OK | os.X_OK)
 
 
 def initialise():
     """Called when `FSLeyes`` is started as a standalone application.  This
     function *must* be called before most other things in *FSLeyes* are used.
-
-    Does a few initialisation steps::
-
-      - Initialises the :mod:`fsl.utils.settings` module, for persistent
-        storage  of application settings.
-
-      - Sets the :data:`assetDir` attribute.
     """
-
-    global assetDir
-
     import fsleyes.plugins as plugins
 
     # implement various hacks and workarounds
@@ -269,36 +259,6 @@ def initialise():
     import fsleyes.frame                 # noqa
     import fsleyes.actions.frameactions  # noqa
 
-    fsleyesDir = op.dirname(__file__)
-    assetDir   = None
-    options    = []
-
-    # If we are running from a bundled
-    # application, we'll guess at the
-    # location, which will differ depending
-    # on the platform
-    if fslplatform.frozen:
-        mac = op.join(fsleyesDir, '..', '..', '..', '..', 'Resources')
-        lnx = op.join(fsleyesDir, '..', 'share', 'FSLeyes')
-        options.append(op.normpath(mac))
-        options.append(op.normpath(lnx))
-
-    # Otherwise we are running from a code install,
-    # or from a source distribution. The assets
-    # directory is either inside, or alongside, the
-    # FSLeyes package directory.
-    else:
-        options = [op.join(fsleyesDir, '..'), fsleyesDir]
-
-    for opt in options:
-        if op.exists(op.join(opt, 'assets')):
-            assetDir = op.abspath(opt)
-            break
-
-    if assetDir is None:
-        raise RuntimeError('Could not find FSLeyes asset directory! '
-                           'Searched: {}'.format(options))
-
 
 def _hacksAndWorkarounds():
     """Called by :func:`initialise`. Implements hacks and workarounds for
@@ -310,27 +270,6 @@ def _hacksAndWorkarounds():
     # before a wx.App has been created
     import wx.html  # noqa
 
-    # PyInstaller 3.2.1 forces matplotlib to use a
-    # temporary directory for its settings and font
-    # cache, and then deletes the directory on exit.
-    # This is silly, because the font cache can take
-    # a long time to create.  Clearing the environment
-    # variable should cause matplotlib to use
-    # $HOME/.matplotlib (or, failing that, a temporary
-    # directory).
-    #
-    # https://matplotlib.org/faq/environment_variables_faq.html#\
-    #   envvar-MPLCONFIGDIR
-    #
-    # https://github.com/pyinstaller/pyinstaller/blob/v3.2.1/\
-    #   PyInstaller/loader/rthooks/pyi_rth_mplconfig.py
-    #
-    # n.b. This will cause issues if building FSLeyes
-    #      with the pyinstaller '--onefile' option, as
-    #      discussed in the above pyinstaller file.
-    if fslplatform.frozen:
-        os.environ.pop('MPLCONFIGDIR', None)
-
     # nibabel rejects NIfTI images where the
     # quaternion vector has a length greater
     # than 1. This is fine, as it is mandated
@@ -354,20 +293,10 @@ def _hacksAndWorkarounds():
     except ValueError:
         os.environ['LC_ALL'] = 'C.UTF-8'
 
-    # Add the current directory to the python
-    # path, so that modules can be imported
-    # from within notebook/shell environments
-    if fslplatform.frozen:
-        sys.path.insert(0, '')
-
 
 def configLogging(verbose=0, noisy=None):
     """Configures *FSLeyes* ``logging``.
 
-    .. note:: All logging calls are usually stripped from frozen
-              versions of *FSLeyes*, so this function does nothing
-              when we are running a frozen version.
-
     :arg verbose: A number between 0 and 3, indicating the verbosity level.
     :arg noisy:   A sequence of module names - logging will be enabled on these
                   modules.
@@ -382,12 +311,6 @@ def configLogging(verbose=0, noisy=None):
     if noisy is None:
         noisy = []
 
-    # Show deprecations if running from code
-    if fslplatform.frozen:
-        warnings.filterwarnings('ignore', category=DeprecationWarning)
-    else:
-        warnings.filterwarnings('default', category=DeprecationWarning)
-
     # Set up the root logger
     logFormatter = logging.Formatter('%(levelname)8.8s '
                                      '%(filename)20.20s '
@@ -403,12 +326,13 @@ def configLogging(verbose=0, noisy=None):
     # Everything below this point sets up verbosity
     # as requested by the user. But verbosity-related
     # command line arguments are not exposed to the
-    # user in frozen versions of FSLeyes, so if we're
-    # running as a frozen app, there's nothing else
-    # to do.
+    # user if disableLogging is set.
     if disableLogging:
         return
 
+    # show dep warnings
+    warnings.filterwarnings('default', category=DeprecationWarning)
+
     # Now we can set up logging
     if verbose == 1:
         log.setLevel(logging.DEBUG)
@@ -437,3 +361,7 @@ def configLogging(verbose=0, noisy=None):
     traceLogger = logging.getLogger('fsleyes_props.trace')
     if traceLogger.getEffectiveLevel() <= logging.DEBUG:
         import fsleyes_props.trace  # noqa
+
+
+# Just for convenience
+from fsleyes.main import embed, shutdown  # noqa
