@@ -11,7 +11,7 @@ functionality to edit the data in an :class:`.Image` overlay.
 
 import logging
 
-import collections
+import collections.abc as abc
 
 import numpy as np
 
@@ -28,9 +28,9 @@ class Editor(actions.ActionProvider):
     specific ``Image`` overlay, passed to :meth:`__init__`.
 
 
-    An ``Editor`` instance uses a :class:`.Selection` object which allows
-    voxel selections to be made, and keeps track of all changes to both the
-    selection and image data.
+    An ``Editor`` instance uses a :class:`.selection.Selection` object which
+    allows voxel selections to be made, and keeps track of all changes to both
+    the selection and image data.
 
 
     **The editing process**
@@ -43,10 +43,9 @@ class Editor(actions.ActionProvider):
      2. Change the value of voxels in that selection
 
 
-    The first step can be peformed by working directly with the
-    :class:`.Selection` object - this is accessible via the
-    :meth:`getSelection` method. The :meth:`fillSelection` method can be used
-    to perform the second step.
+    The first step can be peformed by working directly with the ``Selection``
+    object - this is accessible via the :meth:`getSelection` method. The
+    :meth:`fillSelection` method can be used to perform the second step.
 
 
     Some convenience methods are also provided for working with selections:
@@ -64,7 +63,7 @@ class Editor(actions.ActionProvider):
 
 
     An ``Editor`` instance keeps track of all changes made to the
-    :class:`Image` data and to the :class:`.Selection.  Every selection/data
+    :class:`Image` data and to the ``Selection``  Every selection/data
     change made is recorded using :class:`SelectionChange` and
     :class:`.ValueChange` instances, which are stored in a list. These changes
     can be undone (and redone), through the :meth:`undo` and :meth:`redo`
@@ -101,17 +100,16 @@ class Editor(actions.ActionProvider):
 
         :arg displayCtx:      The :class:`.DisplayContext` instance.
 
-        :arg recordSelection: Defaults to ``False``. If ``True``, changes
-                              to the :class:`.Selection` are recorded in the
-                              change history.
+        :arg recordSelection: Defaults to ``False``. If ``True``, changes to
+                              the :class:`.selection.Selection` are recorded
+                              in the change history.
         """
 
-        self.__name           = '{}_{}'.format(self.__class__.__name__,
-                                               id(self))
-        self.__image          = image
-        self.__overlayList    = overlayList
-        self.__displayCtx     = displayCtx
-        self.__selection      = selection.Selection(
+        actions.ActionProvider.__init__(self, overlayList, displayCtx)
+
+        self.__name      = '{}_{}'.format(self.__class__.__name__, id(self))
+        self.__image     = image
+        self.__selection = selection.Selection(
             image, displayCtx.getDisplay(image))
 
         if recordSelection:
@@ -146,38 +144,36 @@ class Editor(actions.ActionProvider):
         """Removes some property listeners, and clears references to objects
         to prevent memory leaks.
         """
-
-        self.__selection  .deregister(self.__name)
-        self.__overlayList.removeListener('overlays',  self.__name)
-
-        self.__image          = None
-        self.__overlayList    = None
-        self.__displayCtx     = None
-        self.__selection      = None
-        self.__currentOverlay = None
-        self.__doneList       = None
+        actions.ActionProvider.destroy(self)
+        self.__selection.deregister(self.__name)
+        self.__image     = None
+        self.__selection = None
+        self.__doneList  = None
 
 
     def getImage(self):
-        """Returns the :class:`~fsl.dat.image.Image` associated with this
+        """Returns the :class:`~fsl.data.image.Image` associated with this
         ``Editor``.
         """
         return self.__image
 
 
     def getSelection(self):
-        """Returns the :class:`.Selection` instance currently in use. """
+        """Returns the :class:`.selection.Selection` instance currently in use.
+        """
         return self.__selection
 
 
-    def clearSelection(self):
-        """Clears the :class:`.Selection` (see
-        :meth:`.Selection.clearSelection`). If this ``Editor`` is not
-        recording all selection changes (``recordSelection=False`` in
-        :meth:`__init__`), the selection state before being cleared
-        is saved in the change history.
+    def clearSelection(self, *args, **kwargs):
+        """Clears the :class:`.selection.Selection` (see
+        :meth:`.selection.Selection.clearSelection`). If this ``Editor`` is
+        not recording all selection changes (``recordSelection=False`` in
+        :meth:`__init__`), the selection state before being cleared is saved
+        in the change history.
+
+        All arguments are passed through to :meth:`.Selection.clearSelection`.
         """
-        self.__selection.clearSelection()
+        self.__selection.clearSelection(*args, **kwargs)
 
         if (not self.__recordSelection) and self.__recordChanges:
 
@@ -190,6 +186,19 @@ class Editor(actions.ActionProvider):
                 self.__changeMade(change)
 
 
+    def invertSelection(self):
+        """Inverts the current selection. """
+
+        image    = self.__image
+        sel      = self.__selection.getSelection()
+        inverted = np.array(sel == 0, dtype=np.uint8)
+
+        change = SelectionChange(image, (0, 0, 0), sel, inverted)
+
+        self.__applyChange(change)
+        self.__changeMade( change)
+
+
     def fillSelection(self, newVals):
         """Fills the current selection with the specified value or values.
 
@@ -198,10 +207,10 @@ class Editor(actions.ActionProvider):
         """
 
         image               = self.__image
-        opts                = self.__displayCtx.getOpts(image)
+        opts                = self.displayCtx.getOpts(image)
         selectBlock, offset = self.__selection.getBoundedSelection()
 
-        if not isinstance(newVals, collections.Sequence):
+        if not isinstance(newVals, abc.Sequence):
             nv = np.zeros(selectBlock.shape, dtype=np.float32)
             nv.fill(newVals)
             newVals = nv
@@ -302,7 +311,7 @@ class Editor(actions.ActionProvider):
 
         change = self.__doneList[self.__doneIndex]
 
-        if not isinstance(change, collections.Sequence):
+        if not isinstance(change, abc.Sequence):
             change = [change]
 
         for c in reversed(change):
@@ -334,7 +343,7 @@ class Editor(actions.ActionProvider):
 
         change = self.__doneList[self.__doneIndex + 1]
 
-        if not isinstance(change, collections.Sequence):
+        if not isinstance(change, abc.Sequence):
             change = [change]
 
         for c in change:
@@ -360,7 +369,7 @@ class Editor(actions.ActionProvider):
         """
 
         image     = self.__image
-        opts      = self.__displayCtx.getOpts(image)
+        opts      = self.displayCtx.getOpts(image)
         selection = np.array(self.__selection.getSelection() > 0)
         data      = np.zeros(image.shape[:3], dtype=image.dtype)
 
@@ -379,8 +388,8 @@ class Editor(actions.ActionProvider):
         the ``Image`` managed by this instance.
         """
 
-        data, selection = clipboard
-        self.__image[selection] = data[selection]
+        data, sel = clipboard
+        self.__image[sel] = data[sel]
 
 
     def __selectionChanged(self, *a):
@@ -435,16 +444,16 @@ class Editor(actions.ActionProvider):
         """
 
         image = change.overlay
-        opts  = self.__displayCtx.getOpts(image)
+        opts  = self.displayCtx.getOpts(image)
 
         if isinstance(change, ValueChange):
-            log.debug('{}: changing image {} data - offset '
-                      '{}, volume {}, size {}'.format(
-                          self.__image.name,
-                          change.overlay.name,
-                          change.offset,
-                          change.volume,
-                          change.oldVals.shape))
+            log.debug('%s: changing image %s data - offset '
+                      '%s, volume %s, size %s',
+                      self.__image.name,
+                      change.overlay.name,
+                      change.offset,
+                      change.volume,
+                      change.oldVals.shape)
 
             sliceobj = self.__makeSlice(change.offset,
                                         change.newVals.shape,
@@ -465,7 +474,7 @@ class Editor(actions.ActionProvider):
         """
 
         image = change.overlay
-        opts  = self.__displayCtx.getOpts(image)
+        opts  = self.displayCtx.getOpts(image)
 
         if isinstance(change, ValueChange):
             log.debug('{}: reverting image {} data change - offset '
@@ -536,8 +545,9 @@ class ValueChange(object):
 
 
 class SelectionChange(object):
-    """Represents a change which has been made to a :class:`.Selection`
-    instance. Stores the location, the old selection, and the new selection.
+    """Represents a change which has been made to a
+    :class:`.selection.Selection` instance. Stores the location, the old
+    selection, and the new selection.
     """
 
 
