@@ -13,25 +13,12 @@ import logging
 
 import wx
 
-import fsl.utils.idle                              as idle
-import fsl.utils.deprecated                        as deprecated
-import fsleyes_props                               as props
-
-import fsleyes.actions                             as actions
-import fsleyes.displaycontext                      as displayctx
-import fsleyes.controls.overlaylistpanel           as overlaylistpanel
-import fsleyes.controls.overlayinfopanel           as overlayinfopanel
-import fsleyes.controls.atlaspanel                 as atlaspanel
-import fsleyes.controls.overlaydisplaytoolbar      as overlaydisplaytoolbar
-import fsleyes.controls.overlaydisplaypanel        as overlaydisplaypanel
-import fsleyes.controls.canvassettingspanel        as canvassettingspanel
-import fsleyes.controls.locationpanel              as locationpanel
-import fsleyes.controls.clusterpanel               as clusterpanel
-import fsleyes.controls.lookuptablepanel           as lookuptablepanel
-import fsleyes.controls.melodicclassificationpanel as melclasspanel
-import fsleyes.controls.filetreepanel              as filetreepanel
-from . import                                         colourbarpanel
-from . import                                         viewpanel
+import fsl.utils.idle         as idle
+import fsleyes_props          as props
+import fsleyes.actions        as actions
+import fsleyes.displaycontext as displayctx
+from . import                    colourbarpanel
+from . import                    viewpanel
 
 
 log = logging.getLogger(__name__)
@@ -69,6 +56,9 @@ class CanvasPanel(viewpanel.ViewPanel):
       4. Override the :meth:`centrePanelLayout` method if any custom layout is
          necessary.
 
+      5. Call :meth:`.ViewPanel.initProfile` with the initial interaction
+         profile
+
 
     **Actions**
 
@@ -85,18 +75,6 @@ class CanvasPanel(viewpanel.ViewPanel):
        toggleMovieMode
        toggleDisplaySync
        toggleVolumeSync
-       toggleOverlayList
-       toggleOverlayInfo
-       toggleAtlasPanel
-       toggleDisplayToolBar
-       toggleDisplayPanel
-       toggleCanvasSettingsPanel
-       toggleLocationPanel
-       toggleClusterPanel
-       toggleLookupTablePanel
-       toggleClassificationPanel
-       toggleFileTreePanel
-
 
     .. _canvaspanel-adding-content:
 
@@ -237,6 +215,8 @@ class CanvasPanel(viewpanel.ViewPanel):
 
         :arg displayCtx:   The :class:`.DisplayContext` instance.
 
+        :arb frame:        The :class:`.FSLeyesFrame` instance.
+
         :arg sceneOpts:    A :class:`.SceneOpts` instance for this
                            ``CanvasPanel`` - must be created by
                            sub-classes.
@@ -426,109 +406,6 @@ class CanvasPanel(viewpanel.ViewPanel):
         pass
 
 
-    @actions.toggleControlAction(overlaylistpanel.OverlayListPanel)
-    def toggleOverlayList(self):
-        """Toggles an :class:`.OverlayListPanel`. See
-        :meth:`.ViewPanel.togglePanel`.
-        """
-        self.togglePanel(overlaylistpanel.OverlayListPanel, location=wx.BOTTOM)
-
-
-    @actions.toggleControlAction(overlayinfopanel.OverlayInfoPanel)
-    def toggleOverlayInfo(self, floatPane=False):
-        """Toggles an :class:`.OverlayInfoPanel`. See
-        :meth:`.ViewPanel.togglePanel`.
-        """
-        self.togglePanel(overlayinfopanel.OverlayInfoPanel,
-                         location=wx.RIGHT,
-                         floatPane=floatPane)
-
-
-    @actions.toggleControlAction(atlaspanel.AtlasPanel)
-    def toggleAtlasPanel(self):
-        """Toggles an :class:`.AtlasPanel`. See
-        :meth:`.ViewPanel.togglePanel`.
-        """
-        self.togglePanel(atlaspanel.AtlasPanel, location=wx.BOTTOM)
-
-
-    @actions.toggleControlAction(overlaydisplaytoolbar.OverlayDisplayToolBar)
-    def toggleDisplayToolBar(self):
-        """Toggles an :class:`.OverlayDisplayToolBar`. See
-        :meth:`.ViewPanel.togglePanel`.
-        """
-        self.togglePanel(overlaydisplaytoolbar.OverlayDisplayToolBar,
-                         viewPanel=self)
-
-
-    @actions.toggleControlAction(overlaydisplaypanel.OverlayDisplayPanel)
-    def toggleDisplayPanel(self, floatPane=False):
-        """Toggles an :class:`.OverlayDisplayPanel`. See
-        :meth:`.ViewPanel.togglePanel`.
-        """
-        self.togglePanel(overlaydisplaypanel.OverlayDisplayPanel,
-                         floatPane=floatPane,
-                         location=wx.LEFT)
-
-
-    @actions.toggleControlAction(canvassettingspanel.CanvasSettingsPanel)
-    def toggleCanvasSettingsPanel(self, floatPane=False):
-        """Toggles a :class:`.CanvasSettingsPanel`. See
-        :meth:`.ViewPanel.togglePanel`.
-        """
-        self.togglePanel(canvassettingspanel.CanvasSettingsPanel,
-                         canvasPanel=self,
-                         floatPane=floatPane,
-                         location=wx.LEFT)
-
-
-    @actions.toggleControlAction(locationpanel.LocationPanel)
-    def toggleLocationPanel(self):
-        """Toggles a :class:`.LocationPanel`. See
-        :meth:`.ViewPanel.togglePanel`.
-        """
-        from fsleyes.views.orthopanel import OrthoPanel
-
-        # location history only shown in ortho panels
-        self.togglePanel(locationpanel.LocationPanel,
-                         showHistory=isinstance(self, OrthoPanel),
-                         location=wx.BOTTOM)
-
-
-    @actions.toggleControlAction(clusterpanel.ClusterPanel)
-    def toggleClusterPanel(self):
-        """Toggles a :class:`.ClusterPanel`. See
-        :meth:`.ViewPanel.togglePanel`.
-        """
-        self.togglePanel(clusterpanel.ClusterPanel, location=wx.TOP)
-
-
-    @actions.toggleControlAction(lookuptablepanel.LookupTablePanel)
-    def toggleLookupTablePanel(self):
-        """Toggles a :class:`.LookupTablePanel`. See
-        :meth:`.ViewPanel.togglePanel`.
-        """
-        self.togglePanel(lookuptablepanel.LookupTablePanel, location=wx.RIGHT)
-
-
-    @actions.toggleControlAction(melclasspanel.MelodicClassificationPanel)
-    def toggleClassificationPanel(self):
-        """Toggles a :class:`.MelodicClassificationPanel`. See
-        :meth:`.ViewPanel.togglePanel`.
-        """
-        self.togglePanel(melclasspanel.MelodicClassificationPanel,
-                         location=wx.RIGHT,
-                         canvasPanel=self)
-
-
-    @actions.toggleControlAction(filetreepanel.FileTreePanel)
-    def toggleFileTreePanel(self):
-        """Toggles a :class:`.FileTreePanel`. See
-        :meth:`.ViewPanel.togglePanel`.
-        """
-        self.togglePanel(filetreepanel.FileTreePanel, location=wx.RIGHT)
-
-
     @property
     def sceneOpts(self):
         """Returns the :class:`.SceneOpts` instance used by this
@@ -568,45 +445,6 @@ class CanvasPanel(viewpanel.ViewPanel):
         return None
 
 
-    @deprecated.deprecated('0.16.0', '1.0.0', 'Use sceneOpts instead')
-    def getSceneOptions(self):
-        """Returns the :class:`.SceneOpts` instance used by this
-        ``CanvasPanel``.
-        """
-        return self.__opts
-
-
-    @deprecated.deprecated('0.16.0', '1.0.0', 'Use contentPanel instead')
-    def getContentPanel(self):
-        """Returns the ``wx.Panel`` to which sub-classes must add their content.
-        See the note on :ref:`adding content <canvaspanel-adding-content>`.
-        """
-        return self.__contentPanel
-
-
-    @deprecated.deprecated('0.16.0', '1.0.0', 'Use containerPanel instead')
-    def getContainerPanel(self):
-        """Returns the ``wx.Panel`` which contains the
-        :class:`.ColourBarPanel` if it is being displayed, and the content
-        panel. See the note on
-        :ref:`adding content <canvaspanel-adding-content>`.
-        """
-        return self.__containerPanel
-
-
-    @deprecated.deprecated('0.16.0', '1.0.0', 'Use colourBarCanvas instead')
-    def getColourBarCanvas(self):
-        """If a colour bar is being displayed, this method returns
-        the :class:`.ColourBarCanvas` instance which is used by the
-        :class:`.ColourBarPanel` to render the colour bar.
-
-        Otherwise, ``None`` is returned.
-        """
-        if self.__colourBar is not None:
-            return self.__colourBar.getCanvas()
-        return None
-
-
     def getGLCanvases(self):
         """This method must be overridden by subclasses, and must return a
         list containing all :class:`.SliceCanvas` instances which are being
